@@ -15,7 +15,7 @@ import gdata.geo
 
 from caritang.common import version 
 
-version.getInstance().submitRevision("$Revision: 19 $")
+version.getInstance().submitRevision("$Revision: 36 $")
 
 NOT_YET_IMPLEMENTED = 'not yet implemented'
 
@@ -25,13 +25,25 @@ class DocStorage(object):
     '''
     
     def store(self, doc):
+        '''
+        Store the docItem
+        '''
         raise RuntimeError(NOT_YET_IMPLEMENTED)
     
     def canStore(self, doc):
         '''
-        Test is this storage can store the document
+        Test is this storage can store the document.
+        The document is e DocItem
         '''
         raise RuntimeError(NOT_YET_IMPLEMENTED)
+    
+    def getName(self):
+        '''
+        The name of the storage
+        '''
+        raise RuntimeError(NOT_YET_IMPLEMENTED)
+    
+    
 
 class CaritangStorageException(Exception):
     pass
@@ -46,6 +58,10 @@ class AggregatorStorage(DocStorage):
     def __init__(self):
         self.storages = []
 
+    def getName(self):
+        return "aggregator"
+
+
     def store(self, doc):
         capables = filter(lambda(storage): storage.canStore(doc), self.storages)
         if len(capables) == 0:
@@ -90,7 +106,7 @@ class Picassa(DocStorage):
         self.ensure_destination_folder()
 
     def canStore(self, doc):
-        type = mimetypes.guess_type(doc,strict=False)[0]    
+        type = mimetypes.guess_type(doc.getName(),strict=False)[0]    
         if type == "image/jpeg" \
            or type == "video/mp4" :
             return True
@@ -104,28 +120,29 @@ class Picassa(DocStorage):
         Check existence of destination folder and create it if needed
         '''
         if self.album is not None:
-            albums = self.gd_client.GetUserFeed()            
+            albums = self.gd_client.GetUserFeed()           
             remoteAlbum = filter(lambda(entry): entry.title.text == self.album, albums.entry)
-            if len(remoteAlbum) == 0 :
-                self.album_entry = self.gd_client.InsertAlbum(title=self.album, summary='Album for N900 media')
+            if len(remoteAlbum) == 0 :                
+                self.album_entry = self.gd_client.InsertAlbum(title=self.album, summary='Album created by Caritang', access='protected')                
             else :
                 self.album_entry = remoteAlbum[0]    
     
-    def store(self, doc):
+    def store(self, docItem):
         '''
         store the given doc to the storage
         '''      
+        doc = docItem.getFile()
         type = mimetypes.guess_type(doc,strict=False)[0]        
         photoName = os.path.basename(doc)
         if self.album is None:
             photo = self.gd_client.InsertPhotoSimple('/data/feed/api/user/default/albumid/default', photoName, 
-                                               'Uploaded using the API', doc, content_type=type)
+                                               'Uploaded with Caritang', doc, content_type=type)
         else :
             album_url = '/data/feed/api/user/%s/albumid/%s' % (self.login, self.album_entry.gphoto_id.text)
             photo = self.gd_client.InsertPhotoSimple(album_url, photoName, 
-                            'Uploaded using the API', doc, content_type=type)                   
+                            'Uploaded with Caritang', doc, content_type=type)                   
 
-        
+            
                
             
         
@@ -172,10 +189,11 @@ class GoogleDocs(DocStorage):
                 self.folder_entry = remoteFolder[0]    
    
     
-    def store(self, doc):
+    def store(self, docItem):
         '''
         store the given doc to the storage
         '''      
+        doc = docItem.getFile()
         type = mimetypes.guess_type(doc,strict=False)[0]        
                
         ms = gdata.MediaSource(file_path=doc, content_type=type)
